==> Murmur-0.1.0.tar.gz: Murmur-0.1.0/setup.py <==
# -*- coding: utf-8 -*-
"""
Murmur Hash Library
========

Murmur Hash Library is a simple c level implementation developed for
high speed hashing of in memory strings, on disk files, and the contents 
of zip files. 

As the name implies the hashes are generated via an implementation of 
`MurmurHash 2.0`_. 

A few quick NOTES and WARNINGS:

The implementation of MurMur that is used in this code makes the 
following assumptions about your machine:

	1. A 4-byte value can be read from any address without crashing
	2. sizeof(int) == 4

It will also not produce the same results on little-endian and big-endian 
machines.

I believe it would be easily possible to get around these limitations.

.. _MurmurHash 2.0: http://murmurhash.googlepages.com/
"""
import ez_setup
ez_setup.use_setuptools()

from setuptools import setup, Extension

setup(
    name='Murmur',
    version='0.1.0',
    license='MIT',
    author='Bryan McLemore',
    author_email='kaelten@gmail.com',
    description='Provides fast c level murmur hashes',
    zip_safe=False, # I'm not sure if it is egg safe so I'm erring on the side of caution.
    long_description=__doc__,
	ext_modules = [
		Extension('murmur', 
		["murmur/murmur.cpp", "murmur/unzip.c", "murmur/ioapi.c"],
		include_dirs=['murmur/include'],
		libraries=['z'])
	],
    platforms='any',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: C++',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)

==> Murmur-0.1.1.tar.gz: Murmur-0.1.1/setup.py <==
# -*- coding: utf-8 -*-
"""
Murmur Hash Library
========

Murmur Hash Library is a simple c level implementation developed for
high speed hashing of in memory strings, on disk files, and the contents 
of zip files. 

As the name implies the hashes are generated via an implementation of 
`MurmurHash 2.0`_. 

A few quick NOTES and WARNINGS:

The implementation of MurMur that is used in this code makes the 
following assumptions about your machine:

	1. A 4-byte value can be read from any address without crashing
	2. sizeof(int) == 4

It will also not produce the same results on little-endian and big-endian 
machines.

I believe it would be easily possible to get around these limitations.

.. _MurmurHash 2.0: http://murmurhash.googlepages.com/
"""
import ez_setup
ez_setup.use_setuptools()

from setuptools import setup, Extension

setup(
    name='Murmur',
    version='0.1.1',
    license='MIT',
    author='Bryan McLemore',
    author_email='kaelten@gmail.com',
    description='Provides fast murmur hashes for strings, files, and ziped files.',
    zip_safe=False, # I'm not sure if it is egg safe so I'm erring on the side of caution.
    long_description=__doc__,
	ext_modules = [
		Extension('murmur', 
		[	"murmur/murmur.cpp", 
			"murmur/unzip.c", 
			"murmur/ioapi.c", 
		],
		depends=[
			"murmur/include/crypt.h", 
			"murmur/include/ioapi.h",
			"murmur/include/unzip.h",
		],
		include_dirs=['murmur/include'],
		libraries=['z'],
		language='c++')
	],
    platforms='any',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: C++',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ],
)
